@@ -1,12 +1,9 @@
 
 set.seed(290875)
-gctorture(on = FALSE)
-library(party)
-gctorture(on = GCtorture)
+library("party")
 
 ### get rid of the NAMESPACE
-nsparty <- attach(NULL, name="ns-party")
-.Internal(lib.fixup(asNamespace("party"), nsparty))
+attach(asNamespace("party"))
 
 ### 
 ###
